@@ -30,6 +30,7 @@ MA 02139, USA.
 #endif
 
 #include "common.h"
+#include "files.h"
 #include "pacct_rd.h"
 #ifdef HAVE_GETOPT_LONG_ONLY
 #include <getopt.h>
@@ -43,7 +44,7 @@ int debugging_enabled = 0;	/* no -- we don't care about bad
 				   algorithms. */
 int ahz = AHZ;
 
-static void give_usage(void)
+void give_usage(void)
 {
   printf ("Usage: %s [-hrR] [-n <recs>] <files>\n\
           [--num <recs>] [--raw] [--reverse] [--help]\n",
@@ -74,19 +75,19 @@ int main(int argc, char *argv[])
       int option_index = 0;
 
       static struct option long_options[] =
-        {
-          { "reverse", no_argument, NULL, 1
-          },
-          { "help", no_argument, NULL, 2 },
-          { "num", required_argument, NULL, 3 },
-          { "raw", no_argument, NULL, 4 },
-          { "ahz", required_argument, NULL, 5 },
+      {
+        { "reverse", no_argument, NULL, 1
+        },
+        { "help", no_argument, NULL, 2 },
+        { "num", required_argument, NULL, 3 },
+        { "raw", no_argument, NULL, 4 },
+        { "ahz", required_argument, NULL, 5 },
 #ifdef LINUX_MULTIFORMAT
-          { "format", required_argument, NULL, 6 },
-          { "byteswap", no_argument, NULL, 7 },
+        { "format", required_argument, NULL, 6 },
+        { "byteswap", no_argument, NULL, 7 },
 #endif
-          { 0, 0, 0, 0 },
-        };
+        { 0, 0, 0, 0 },
+      };
 
       c = getopt_long (argc, argv, "rhn:R", long_options, &option_index);
 
@@ -117,7 +118,7 @@ int main(int argc, char *argv[])
           ahz = strtol(optarg, (char **)NULL, 10);
           if (ahz < 1)
             {
-              printf ("%s: AHZ must be one or greater\n", program_name);
+              (void)printf ("%s: AHZ must be one or greater\n", program_name);
               exit (EXIT_FAILURE);
             }
           break;
