@@ -1162,31 +1162,30 @@ void parse_acct_entries (void)
 # define CURR_AHZ ((double)(ahz))
 #endif
 
-
   if (debugging_enabled)
     fprintf (stddebug, "\
              ----------------------------------------------------------------------\n\
              acct entries\n\
              ----------------------------------------------------------------------\n\
              ");
-
+             
   /* loop while there are entries to be had */
   while ((rec = pacct_get_entry ()) != NULL)
     {
 #ifdef HAVE_ACUTIME
-      double ut = comp_t_2_double (rec->ac_utime) / (double) hzval;
+      double ut = comp_t_2_double (rec->ac_utime) / CURR_AHZ;
 #endif
 
 #ifdef HAVE_ACSTIME
-      double st = comp_t_2_double (rec->ac_stime) / (double) hzval;
+      double st = comp_t_2_double (rec->ac_stime) / CURR_AHZ;
 #endif
 
 #ifdef HAVE_ACETIME
-      double et = comp_t_2_double (rec->ac_etime) / (double) hzval;
+      double et = ACETIME_2_DOUBLE (rec->ac_etime) / CURR_AHZ;
 #endif
 
 #ifdef HAVE_ACIO
-      double di = comp_t_2_double (rec->ac_io) / (double) hzval;
+      double di = comp_t_2_double (rec->ac_io) / CURR_AHZ;
 #endif
 
 #ifdef HAVE_ACMEM
